==> koffice-trinity-14.1.2.tar.xz: koffice-trinity-14.1.2/kformula/formulastring.h <==
/* This file is part of the KDE project
   Copyright (C) 2002 Ulrich Kuettler <ulrich.kuettler@mailbox.tu-dresden.de>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef FORMULASTRING_H
#define FORMULASTRING_H

#include <tqvariant.h>
#include <tqdialog.h>

class TQGridLayout;
class TQHBoxLayout;
class TQLabel;
class TQPushButton;
class TQTextEdit;
class TQVBoxLayout;

class KFormulaPartView;

class FormulaString : public TQDialog
{
    TQ_OBJECT
  

public:
    FormulaString( KFormulaPartView* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~FormulaString();

    TQTextEdit* textWidget;
    TQPushButton* buttonHelp;
    TQPushButton* buttonOk;
    TQPushButton* buttonCancel;
    TQLabel* position;

protected slots:

    virtual void accept ();
    void helpButtonClicked();

    void cursorPositionChanged ( int para, int pos );

private:
    KFormulaPartView* view;
};

#endif // FORMULASTRING_H

==> koffice-trinity-14.1.5.tar.xz: koffice-trinity-14.1.5/kformula/formulastring.h <==
/* This file is part of the KDE project
   Copyright (C) 2002 Ulrich Kuettler <ulrich.kuettler@mailbox.tu-dresden.de>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef FORMULASTRING_H
#define FORMULASTRING_H

#include <tqvariant.h>
#include <tqdialog.h>

class TQGridLayout;
class TQHBoxLayout;
class TQLabel;
class TQPushButton;
class TQTextEdit;
class TQVBoxLayout;

class KFormulaPartView;

class FormulaString : public TQDialog
{
    TQ_OBJECT
  

public:
    FormulaString( KFormulaPartView* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );
    ~FormulaString();

    TQTextEdit* textWidget;
    TQPushButton* buttonHelp;
    TQPushButton* buttonOk;
    TQPushButton* buttonCancel;
    TQLabel* position;

protected slots:

    virtual void accept ();
    void helpButtonClicked();

    void cursorPositionChanged ( int para, int pos );

private:
    KFormulaPartView* view;
};

#endif // FORMULASTRING_H
